pysorteddict
============

Enriches Python with ``SortedDict``, a sorted dictionary: a dictionary in which the keys are always in ascending order.

pysorteddict is implemented entirely in C++. ``SortedDict`` provides a Python interface to ``std::map``.

.. toctree::
   :maxdepth: 1

   installation
   usage
   documentation
   performance
   changelog
   repository
